@@ -24,8 +24,22 @@
 #include "SyncClientInterface.h"
 #include "SyncClientInterfacePrivate.h"
 
+#include <QDBusPendingCallWatcher>
+
 using namespace Buteo;
 
+QSharedPointer<SyncClientInterface> SyncClientInterface::sharedInstance()
+{
+    static QWeakPointer<SyncClientInterface> sharedObj;
+    QSharedPointer<SyncClientInterface> obj = sharedObj.toStrongRef();
+
+    if (!obj) {
+        obj = QSharedPointer<SyncClientInterface>(new SyncClientInterface);
+        sharedObj = obj;
+    }
+    return obj;
+}
+
 SyncClientInterface::SyncClientInterface():
     d_ptr(new SyncClientInterfacePrivate(this))
 {
@@ -43,27 +57,37 @@ bool SyncClientInterface::startSync(const QString &aProfileId) const
     return d_ptr->startSync(aProfileId);
 }
 
+QDBusPendingCallWatcher* SyncClientInterface::requestSync(const QString &aProfileId, QObject *aParent) const
+{
+    return d_ptr->requestSync(aProfileId, aParent);
+}
+
 void SyncClientInterface::abortSync(const QString &aProfileId) const
 {
     d_ptr->abortSync(aProfileId);
 }
 
-QStringList SyncClientInterface::getRunningSyncList()
+QStringList SyncClientInterface::getRunningSyncList() const
 {
     return d_ptr->getRunningSyncList();
 }
 
-bool SyncClientInterface::removeProfile(QString &aProfileId)
+QDBusPendingCallWatcher* SyncClientInterface::requestRunningSyncList(QObject *aParent) const
+{
+    return d_ptr->requestRunningSyncList(aParent);
+}
+
+bool SyncClientInterface::removeProfile(const QString &aProfileId) const
 {
     return d_ptr->removeProfile(aProfileId);
 }
 
-bool SyncClientInterface::updateProfile(Buteo::SyncProfile &aProfile)
+bool SyncClientInterface::updateProfile(const Buteo::SyncProfile &aProfile)
 {
     return d_ptr->updateProfile(aProfile);
 }
 
-bool SyncClientInterface::setSyncSchedule(QString &aProfileId, SyncSchedule &aSchedule)
+bool SyncClientInterface::setSyncSchedule(const QString &aProfileId, const SyncSchedule &aSchedule)
 {
     return d_ptr->setSyncSchedule(aProfileId, aSchedule);
 }
@@ -78,7 +102,7 @@ bool SyncClientInterface::getBackUpRestoreState()
     return d_ptr->getBackUpRestoreState();
 }
 
-bool SyncClientInterface::isValid()
+bool SyncClientInterface::isValid() const
 {
     return d_ptr->isValid();
 }
@@ -94,6 +118,11 @@ QList<QString /*profileAsXml*/> SyncClientInterface::allVisibleSyncProfiles()
     return d_ptr->allVisibleSyncProfiles();
 }
 
+QDBusPendingCallWatcher* SyncClientInterface::requestAllVisibleSyncProfiles(QObject *aParent) const
+{
+    return d_ptr->requestAllVisibleSyncProfiles(aParent);
+}
+
 
 QString SyncClientInterface::syncProfile(const QString &aProfileId)
 {
@@ -105,7 +134,22 @@ QStringList SyncClientInterface::syncProfilesByKey(const QString &aKey, const QS
     return d_ptr->syncProfilesByKey(aKey, aValue);
 }
 
+QDBusPendingCallWatcher* SyncClientInterface::requestSyncProfilesByKey(const QString &aKey, const QString &aValue, QObject *aParent) const
+{
+    return d_ptr->requestSyncProfilesByKey(aKey, aValue, aParent);
+}
+
 QStringList SyncClientInterface::syncProfilesByType(const QString &aType)
 {
     return d_ptr->syncProfilesByType(aType);
 }
+
+QStringList SyncClientInterface::profilesByType(const QString &aType)
+{
+    return d_ptr->profilesByType(aType);
+}
+
+QDBusPendingCallWatcher* SyncClientInterface::requestProfilesByType(const QString &aType, QObject *aParent) const
+{
+    return d_ptr->requestProfilesByType(aType, aParent);
+}
